Examples
========

The library comes with several examples in the ``examples/`` directory.

Basic API Usage
---------------

.. literalinclude:: ../../examples/demo_simple_api.py
   :language: python
   :caption: examples/demo_simple_api.py

Complete Workflow
-----------------

.. literalinclude:: ../../examples/demo_base.py
   :language: python
   :caption: examples/demo_base.py

Adding Plots
------------

.. literalinclude:: ../../examples/demo_add_plots.py
   :language: python
   :caption: examples/demo_add_plots.py
